@@ -69,7 +69,7 @@ def main():
     print('------------------------\nStarting data diagnostics\n------------------------\n')
 
     print('Calculating number of assigned molecular formulas per sample')
-    diagnostics.formula_per_sample(df, metadata, path=list_dir[1])
+    diagnostics.formula_per_sample(df, metadata, args.group[0], path=list_dir[1])
     print("Calculating error distribution per group/s: {}".format(args.group))
     diagnostics.error_per_group(df, args.group, path=list_dir[1])
 
